# Installing required packages 
install.packages('metafor')

# Loading required packages into the library
library(metafor)

# Reading in log relative risks from separate studies
RR_bystudy <- read.csv('AirPollutionStudies.csv')

# Printing the dataset
RR_bystudy

# Summarising the data 
summary(RR_bystudy)

# Fitting the random effects model
mod <- rma(yi  = beta, # Log RR estimates
sei = se, # Standard error estimates 
slab = Study, # Study name for labelling
data = RR_bystudy, # Dataset
method = 'DL') # Method: FE for Fixed Effects and DL for Random Effects
	
# Summarising meta-analysis
summary(mod)

# Creating a forest plot
forest(mod, # Model
       showweights = TRUE, # Show the contributions from each study
       transf = exp, # Transforming from log relative risk 
       refline = 1, # Reference line, 1 is no increased in risk
       xlab = 'Relative Risk') # x-axis label

# Creating a funnel plot
funnel(mod, # Model
       xlab = 'Relative Risk', # x-axis label
       ylab = 'Standard Error') # y-axis label


